@@ -5,13 +5,13 @@ use once_cell::sync::Lazy;
 pub static TAG_TEXTAREA_END: Lazy<AhoCorasick> = Lazy::new(|| {
   AhoCorasickBuilder::new()
     .ascii_case_insensitive(true)
-    .dfa(true)
     .build(["</textarea"])
+    .unwrap()
 });
 
 pub static TAG_TITLE_END: Lazy<AhoCorasick> = Lazy::new(|| {
   AhoCorasickBuilder::new()
     .ascii_case_insensitive(true)
-    .dfa(true)
     .build(["</title"])
+    .unwrap()
 });
